@@ -26,28 +26,20 @@ extern "C" {
   Define declarations.
 */
 #define MagickPackageName "ImageMagick"
-#define MagickCopyright  "© 1999-2020 ImageMagick Studio LLC"
-#define MagickLibVersion  0x70A
-#define MagickLibVersionText  "7.0.10"
-#define MagickLibVersionNumber  8,0,0
-#define MagickLibAddendum  "-56"
-#define MagickLibInterface  8
-#define MagickLibMinInterface  8
-#if defined(_WINDOWS)
-#  if defined(_WIN64)
-#    define MagickPlatform "x64"
-#  else
-#    define MagickPlatform "x86"
-#  endif
-#else
+#define MagickCopyright  "(C) 1999-2021 ImageMagick Studio LLC"
+#define MagickLibVersion  0x70B
+#define MagickLibVersionText  "7.0.11"
+#define MagickLibVersionNumber  9,0,0
+#define MagickLibAddendum  "-0"
+#define MagickLibInterface  9
+#define MagickLibMinInterface  9
 #define MagickPlatform  "armv5tel"
-#endif
-#define MagickppLibVersionText  "7.0.10"
-#define MagickppLibVersionNumber  4:0:0
-#define MagickppLibAddendum  "-56"
-#define MagickppLibInterface  4
-#define MagickppLibMinInterface  4
-#define MagickReleaseDate  "2021-01-06"
+#define MagickppLibVersionText  "7.0.11"
+#define MagickppLibVersionNumber  5:0:0
+#define MagickppLibAddendum  "-0"
+#define MagickppLibInterface  5
+#define MagickppLibMinInterface  5
+#define MagickReleaseDate  "2021-02-13"
 #define MagickAuthoritativeLicense  \
   "https://imagemagick.org/script/license.php"
 #define MagickAuthoritativeURL  "https://imagemagick.org"
